@@ -28,30 +28,29 @@ DimPlot(data, reduction = "umap", label = TRUE, pt.size = 0.5) + NoLegend()
 net <- get_collectri(organism='human', split_complexes=FALSE)
 net
 
-## ----"wmean", message=FALSE-------------------------------------------------------------------------------------------
+## ----"ulm", message=FALSE---------------------------------------------------------------------------------------------
 # Extract the normalized log-transformed counts
 mat <- as.matrix(data@assays$RNA@data)
 
-# Run wmean
-acts <- run_wmean(mat=mat, net=net, .source='source', .target='target',
-                  .mor='mor', times = 100, minsize = 5)
+# Run ulm
+acts <- run_ulm(mat=mat, net=net, .source='source', .target='target',
+                .mor='mor', minsize = 5)
 acts
 
 ## ----"new_assay", message=FALSE---------------------------------------------------------------------------------------
-# Extract norm_wmean and store it in tfswmean in pbmc
-data[['tfswmean']] <- acts %>%
-  filter(statistic == 'norm_wmean') %>%
+# Extract ulm and store it in tfsulm in pbmc
+data[['tfsulm']] <- acts %>%
   pivot_wider(id_cols = 'source', names_from = 'condition',
               values_from = 'score') %>%
   column_to_rownames('source') %>%
   Seurat::CreateAssayObject(.)
 
 # Change assay
-DefaultAssay(object = data) <- "tfswmean"
+DefaultAssay(object = data) <- "tfsulm"
 
 # Scale the data
 data <- ScaleData(data)
-data@assays$tfswmean@data <- data@assays$tfswmean@scale.data
+data@assays$tfsulm@data <- data@assays$tfsulm@scale.data
 
 ## ----"projected_acts", message = FALSE, warning = FALSE, fig.width = 12, fig.height = 4-------------------------------
 p1 <- DimPlot(data, reduction = "umap", label = TRUE, pt.size = 0.5) + 
@@ -61,13 +60,13 @@ p2 <- (FeaturePlot(data, features = c("PAX5")) &
   ggtitle('PAX5 activity')
 DefaultAssay(object = data) <- "RNA"
 p3 <- FeaturePlot(data, features = c("PAX5")) + ggtitle('PAX5 expression')
-DefaultAssay(object = data) <- "tfswmean"
+DefaultAssay(object = data) <- "tfsulm"
 p1 | p2 | p3
 
 ## ----"mean_acts", message = FALSE, warning = FALSE--------------------------------------------------------------------
 n_tfs <- 25
 # Extract activities from object as a long dataframe
-df <- t(as.matrix(data@assays$tfswmean@data)) %>%
+df <- t(as.matrix(data@assays$tfsulm@data)) %>%
   as.data.frame() %>%
   mutate(cluster = Idents(data)) %>%
   pivot_longer(cols = -cluster, names_to = "source", values_to = "score") %>%
